( cd usr/share/swftools/swfs ; rm -rf default_viewer.swf )
( cd usr/share/swftools/swfs ; ln -sf /tmp/tgz/package/swftools/usr/share/swftools/swfs/simple_viewer.swf default_viewer.swf )
( cd usr/share/swftools/swfs ; rm -rf default_loader.swf )
( cd usr/share/swftools/swfs ; ln -sf /tmp/tgz/package/swftools/usr/share/swftools/swfs/tessel_loader.swf default_loader.swf )
